==> otb_7.2.0+dfsg.orig.tar.xz: Modules/Core/Metadata/include/otbCosmoImageMetadataInterface.h <==
/*
 * Copyright (C) 2005-2020 Centre National d'Etudes Spatiales (CNES)
 *
 * This file is part of Orfeo Toolbox
 *
 *     https://www.orfeo-toolbox.org/
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef otbCosmoImageMetadataInterface_h
#define otbCosmoImageMetadataInterface_h

#include "otbSarImageMetadataInterface.h"


namespace otb
{
/** \class CosmoImageMetadataInterface
 *
 * \brief Creation of an "otb" CosmoImageMetadataInterface that gets metadata.
 *
 *
 * \ingroup OTBMetadata
 */

class OTBMetadata_EXPORT CosmoImageMetadataInterface : public SarImageMetadataInterface
{
public:
  typedef CosmoImageMetadataInterface   Self;
  typedef SarImageMetadataInterface     Superclass;
  typedef itk::SmartPointer<Self>       Pointer;
  typedef itk::SmartPointer<const Self> ConstPointer;

  /** Method for creation through the object factory. */
  itkNewMacro(Self);


  /** Run-time type information (and related methods). */
  itkTypeMacro(CosmoImageMetadataInterface, SarImageMetadataInterface);

  typedef Superclass::ImageType                ImageType;
  typedef Superclass::MetaDataDictionaryType   MetaDataDictionaryType;
  typedef Superclass::VectorType               VectorType;
  typedef Superclass::VariableLengthVectorType VariableLengthVectorType;
  typedef Superclass::ImageKeywordlistType     ImageKeywordlistType;
  typedef Superclass::RealType                 RealType;
  typedef Superclass::LookupDataPointerType    LookupDataPointerType;

  /** Get the imaging production day from the ossim metadata : DATASET_PRODUCTION_DATE metadata variable */
  int GetProductionDay() const override;

  /** Get the imaging production month from the ossim metadata : DATASET_PRODUCTION_DATE metadata variable */
  int GetProductionMonth() const override;

  /** Get the imaging production year from the ossim metadata : DATASET_PRODUCTION_DATE metadata variable */
  int GetProductionYear() const override;

  /** check sensor ID */
  bool CanRead() const override;

  int GetDay() const override;

  int GetMonth() const override;

  int GetYear() const override;

  int GetHour() const override;

  int GetMinute() const override;

  UIntVectorType GetDefaultDisplay() const override;

  /*SarImageMetadataInterface pure virutals rituals */
  double GetPRF() const override;

  double GetRSF() const override;

  double GetRadarFrequency() const override;

  double GetCenterIncidenceAngle() const override;

protected:
  /* class ctor */
  CosmoImageMetadataInterface() = default;

  /* class dtor */
  ~CosmoImageMetadataInterface() = default;

private:
  CosmoImageMetadataInterface(const Self&) = delete;
  void operator=(const Self&) = delete;

  /* Helper function to parse date and time into a std::vector<std::string>
   * using boost::split() expect date time in yyyy-mm-ddThh:mm:ss.ms
   * the date-time string is to be found in keywordlist with key 'key'
   * fills argument dateFields of type std::vector<std::string> which is mutable!
   * TODO: move this method into base class
   */
  void ParseDateTime(std::string key, std::vector<int>& dateFields) const;

  mutable std::vector<int> m_ProductionDateFields;
  mutable std::vector<int> m_AcquisitionDateFields;
};


} // end namespace otb

#endif

==> otb_8.1.1+dfsg.orig.tar.xz: Modules/Core/Metadata/include/otbCosmoImageMetadataInterface.h <==
/*
 * Copyright (C) 2005-2022 Centre National d'Etudes Spatiales (CNES)
 *
 * This file is part of Orfeo Toolbox
 *
 *     https://www.orfeo-toolbox.org/
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef otbCosmoImageMetadataInterface_h
#define otbCosmoImageMetadataInterface_h

#include "otbSarImageMetadataInterface.h"
#include "otbSARMetadata.h"

namespace otb
{
/** \class CosmoImageMetadataInterface
 *
 * \brief Creation of an "otb" CosmoImageMetadataInterface that gets metadata.
 *
 *
 * \ingroup OTBMetadata
 */

class OTBMetadata_EXPORT CosmoImageMetadataInterface : public SarImageMetadataInterface
{
public:
  typedef CosmoImageMetadataInterface   Self;
  typedef SarImageMetadataInterface     Superclass;
  typedef itk::SmartPointer<Self>       Pointer;
  typedef itk::SmartPointer<const Self> ConstPointer;

  /** Method for creation through the object factory. */
  itkNewMacro(Self);


  /** Run-time type information (and related methods). */
  itkTypeMacro(CosmoImageMetadataInterface, SarImageMetadataInterface);

  typedef Superclass::ImageType                ImageType;
  typedef Superclass::MetaDataDictionaryType   MetaDataDictionaryType;
  typedef Superclass::VectorType               VectorType;
  typedef Superclass::VariableLengthVectorType VariableLengthVectorType;
  typedef Superclass::RealType                 RealType;
  typedef Superclass::LookupDataPointerType    LookupDataPointerType;

  double GetCenterIncidenceAngle(const MetadataSupplierInterface&) const override;

  void Parse(ImageMetadata &) override;

  void ParseGdal(ImageMetadata &) override;
  
  void ParseGeom(ImageMetadata &) override;

  std::vector<std::map<std::string, std::string> > saveMetadataBands(std::string file) ;

  std::vector<Orbit> getOrbits(const std::string & referenceTime) const;
  
  std::vector<BurstRecord> CreateBurstRecord(const std::string & firstLineTimeStr,
					     const std::string & lastLineTimeStr,
					     const unsigned long endLine, 
					     const unsigned long endSample) const;

protected:
  /* class ctor */
  CosmoImageMetadataInterface() = default;

  /* class dtor */
  ~CosmoImageMetadataInterface() = default;

private:
  CosmoImageMetadataInterface(const Self&) = delete;
  void operator=(const Self&) = delete;
};


} // end namespace otb

#endif
